@@ -17,7 +17,7 @@ use Net::CIDR::Lite;
 
 #parameter syslog Indicates syslog facility for logging user actions
 
-our $VERSION = '1.3.2';
+our $VERSION = '1.4.0';
 our $_SUPER;
 our @ISA;
 
@@ -272,6 +272,7 @@ a {
     print
       '<center><a href="http://lemonldap-ng.org">LemonLDAP::NG</a></center>';
     print STDERR ( ref($self) || $self ) . " error: $t1, $t2\n";
+    print $cgi->end_html();
     $self->quit();
 }
 
@@ -297,6 +298,7 @@ sub userLog {
     my ( $self, $mess, $level ) = @_;
     if ( $self->{syslog} ) {
         $self->startSyslog();
+        $level =~ s/^warn$/warning/;
         syslog( $level || 'notice', $mess );
     }
     else {
@@ -315,7 +317,7 @@ sub userInfo {
 
 ##@method void userNotice(string mess)
 # Log user actions like access and logout. Alias for userLog() with facility
-# "warn".
+# "notice".
 # @param $mess string to log
 sub userNotice {
     my ( $self, $mess ) = @_;
@@ -325,7 +327,7 @@ sub userNotice {
 
 ##@method void userError(string mess)
 # Log user errors like "bad password". Alias for userLog() with facility
-# "error".
+# "warn".
 # @param $mess string to log
 sub userError {
     my ( $self, $mess ) = @_;
